
!UiAbstractItemView methodsFor: 'initialization' stamp: 'mt 10/20/2010 13:56:11.232'!
initialize

	"Initialize headers."
	verticalHeader := Morph new color: Color transparent; width: self scrollBarThickness; changeTableLayout; listDirection: #topToBottom.
	horizontalHeader := Morph new color: Color transparent; height: self scrollBarThickness; changeTableLayout; listDirection: #leftToRight.
	vHeaderScroller := TransformMorph new color: Color transparent.
	hHeaderScroller := TransformMorph new color: Color transparent.

	super initialize.
	
	self
		borderWidth: 0;
		color: Color white.
	
	"Initialize viewport."
	self scroller addMorph: self viewportClass new.
	self connect: self viewport signal: #focusChanged: toSelector: #scrollToShow:.
	self connect: self viewport signal: #clicked: toSelector: #clicked:.
	self connect: self viewport signal: #doubleClicked: toSelector: #doubleClicked:.
	self connect: self viewport signal: #selectionChanged: toSelector: #selectionChanged:.
	self connect: self viewport signal: #currentIndexChanged: toSelector: #currentIndexChanged:.
	self viewport verticalHeader: verticalHeader.
	self viewport horizontalHeader: horizontalHeader.
	
	"Initialize item delegates."
	itemDelegates := Dictionary new.
	self defaultItemDelegate: UiSimpleItemDelegate new.
	
	"Initialize headers - Finish."
	verticalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #height: pattern: #(2).
	vHeaderScroller addMorph: verticalHeader.

	horizontalHeader connect: self viewport signal: #resizedToWidth:height: toSelector: #width:.
	hHeaderScroller addMorph: horizontalHeader.! !

!UiDiagonaIcons class methodsFor: 'as yet unclassified' stamp: 'mt 10/19/2010 11:21:47.64'!
license

	^ 'Diagona Icons 1.0
	 2007 Yusuke Kamiyamane
	Website: http://p.yusukekamiyamane.com
	License: http://creativecommons.org/licenses/by/3.0'! !

!UiButton class methodsFor: 'properties' stamp: 'mt 7/21/2010 11:43:26.76'!
widgetProperties

	^ {{'Custom'. #yourself} -> {
		#text -> String}}! !

Morph subclass: #UiIconPickerDialog
	instanceVariableNames: 'iconSetCombo iconView infoLabel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Widgets-Dialogs'!

!UiIconPickerDialog commentStamp: 'mt 10/19/2010 11:08:01.295' prior: 0!
A useful dialog to help a developer to choose the right icon.!

!UiIconPickerDialog methodsFor: 'actions' stamp: 'mt 10/14/2010 20:45:34.542'!
changeIconSet: anIndex

	iconView model iconSet: (UiIcons subclasses at: anIndex).! !

!UiIconPickerDialog methodsFor: 'initialization' stamp: 'mt 10/17/2010 10:09:58.568'!
initialize

	super initialize.
	
	iconSetCombo := UiComboBox new hResizing: #spaceFill.
	UiIcons subclassesDo: [:s | iconSetCombo addText: s name].
	self connect: iconSetCombo signal: #currentIndexChanged:text: toSelector: #changeIconSet:.
	
	iconView := UiListIconView new
		listOrientation: #vertical;
		model: (UiIconModel new showText: false);
		hResizing: #spaceFill;
		vResizing: #spaceFill;
		borderStyle: (BorderStyle inset width: 1).
	self connect: iconView signal: #clicked: toSelector: #chooseIcon:.
	
	self
		color: (Color gray: 0.9);
		changeTableLayout;
		listDirection: #topToBottom;
		layoutInset: 5;
		cellInset: 5;
		cellPositioning: #topLeft.
		
	self
		addMorphBack: (UiLabel new text: 'Select an icon set then pick an icon below. The code to get
the form will be copied into the <b>clipboard</b>.' asHtmlText);
		addMorphBack: iconSetCombo;
		addMorphBack: iconView.
		
	"Initial set."
	self changeIconSet: iconSetCombo currentIndex.! !

!UiContainer methodsFor: 'dropping/grabbing' stamp: 'mt 10/19/2010 15:40:56.326'!
acceptDroppingMorph: aMorph event: evt

	(aMorph isKindOf: TransferMorph)
		ifTrue: [ | widgetClass widget |
			widgetClass := aMorph passenger model widgetAt: aMorph passenger.
			widgetClass ifNil: [^ self].
			widget := widgetClass new.
			widget position: evt position.
			self addMorphBack: widget.
			
			(widget isKindOf: UiContainer)
				ifTrue: [widget editMode: self editMode].
			
		^ self].

	^ super acceptDroppingMorph: aMorph event: evt.! !

!UiStackedWidget methodsFor: 'dropping/grabbing' stamp: 'mt 7/16/2010 11:49:38.967'!
acceptDroppingMorph: aMorph event: evt

	(aMorph isKindOf: TransferMorph)
		ifTrue: [ | newMorph |
			newMorph := (Smalltalk at: aMorph passenger contents asSymbol) perform: #new.
			newMorph position: evt position.
			self currentPage addMorphBack: newMorph.
			
			(newMorph isKindOf: UiContainer)
				ifTrue: [newMorph editMode: self editMode]]
		ifFalse: [self currentPage addMorphBack: aMorph].
		
	self updateCurrentPage.! !

!UiPropertyTable methodsFor: 'adding - combined' stamp: 'mt 7/16/2010 11:20:36.162'!
addCustomProperties: aMorph

	| editor |
	aMorph class widgetProperties do: [:category |
		self addSeparator: category key first.
		category value do: [:property | |target|
			target := aMorph perform: category key second.
			editor := self createEditorFor: property value value: (target perform: property key).
			self addPropertyLabel: property key editor: editor.

			"Post editor setup."
			({Integer. Point. String. Float} includes: property value)
				ifTrue: [self connect: editor signal: #valueChanged: to: target selector: (property key, #:) asSymbol].
			(property value isKindOf: Collection)
				ifTrue: [
					editor converter: [:item | item asSymbol]. "Treat elements as symbols."
					self connect: editor signal: #currentIndexChanged:text: to: target selector: (property key, #:) asSymbol pattern: #(2)]]].! !

!UiPropertyTable methodsFor: 'private' stamp: 'mt 7/16/2010 11:03:58.179'!
createEditorFor: listOrClass value: aValue
	"Create the corresponding editor morph and set a start value."
	
	| editor |

	listOrClass == Boolean
		ifTrue: [editor := UiCheckBox new icon: nil; text: nil; checked: aValue].
	listOrClass == String
		ifTrue: [editor := UiLineEdit new theText: aValue.
			editor hResizing: #spaceFill].
	listOrClass == Integer
		ifTrue: [editor := UiLineEdit new theText: aValue; validator: [:raw | raw asInteger ifNil: [0]].
			editor hResizing: #spaceFill].
	listOrClass == Point
		ifTrue: [editor := UiLineEdit new theText: aValue;
			validator: [:raw | |tokens result|
				tokens := raw findTokens: #@.
				tokens ifEmpty: [result := 0@0].
				tokens size = 1 ifTrue: [result := tokens first asInteger @ 0].
				result ifNil: [tokens first asInteger @ tokens second asInteger]];
			hResizing: #spaceFill].
	listOrClass == Float
		ifTrue: [editor := UiLineEdit new theText: aValue; validator: [:raw | [(Float readFrom: raw readStream)] on: Error do: [:e | 0.0]].
			editor hResizing: #spaceFill].
	(listOrClass isKindOf: Collection)
		ifTrue: [editor := UiComboBox new.
			listOrClass do: [:value | editor addText: value asString].
			editor currentIndex: (editor findText: aValue).
			editor hResizing: #spaceFill].
	
	^ editor! !

!UiPropertyTable methodsFor: 'updating' stamp: 'mt 7/16/2010 11:27:47.804'!
updateProperties: aMorph

	lastMorph == aMorph ifTrue: [^ self].
	lastMorph := aMorph.
	
	self
		removeAllMorphs;
		addAllProperties: aMorph;
		removeIgnoredProperties: aMorph;
		updateNameColumnWidth;
		resized.! !

!UiComboBox methodsFor: 'drawing' stamp: 'mt 10/19/2010 19:24:08.043'!
drawOn: aCanvas

	button height ~= self submorphs first
		ifTrue: [button height: self submorphs first height].

	aCanvas
		frameRoundRect: self outerBounds
		radius: 3
		width: 1
		color: self color muchDarker.! !

!UiComboBox methodsFor: 'private' stamp: 'mt 6/29/2010 16:52:35.434'!
hideList

	listWidget delete.
	button checked: false.! !

!UiComboBox methodsFor: 'initialization' stamp: 'mt 10/20/2010 14:56:49.445'!
initialize

	super initialize.
	
	self
		vResizing: #shrinkWrap;
		changeTableLayout;
		listDirection: #leftToRight;
		cellPositioning: #topLeft;
		width: 150.
		
	button := UiToolButton new
		text: nil;
		checkable: true;
		vResizing: #rigid;
		icon: (UiSilkIcons bulletArrowDownIcon clippedTo: 8@8);
		layoutInset: (3@4 corner: 3@4).
	lineEdit := UiLineEdit new
		outerBorderWidth: 0.
	listWidget := UiListWidget new
		borderWidth: 1.
	
	readOnlyButton := UiToolButton new
		text: ' ';
		icon: nil;
		checkable: true;
		hResizing: #spaceFill.
	
	"Initialize the submorphs the first time."
	self readOnly: true.
		
	self connect: listWidget signal: #currentRowChanged: toSelector: #updateCurrentRow:.
	self connect: listWidget signal: #currentRowChanged: toSelector: #hideList.

	self connect: button signal: #toggled: toSelector: #listVisible:.
	self connect: button signal: #pressed toSelector: #showList.

	self connect: readOnlyButton signal: #pressed toSelector: #showList.
	self connect: readOnlyButton signal: #toggled: to: button selector: #checked:.

	self connect: button signal: #toggled: to: readOnlyButton selector: #checked:.
	
	self color: (Color gray: 0.8).! !

!UiComboBox methodsFor: 'private' stamp: 'mt 10/20/2010 14:50:47.379'!
showList

	listWidget
		useOptimalSize;
		width: (self width + 2 max: listWidget width);
		height: (listWidget height min: 100);
		topLeft: (self localPointToGlobal: self bottomLeft) - (1@0);
		openInWorld.! !
